ResponsiveUtils class

A utility class that provides methods to determine the type of device based on the screen width and to retrieve screen dimensions.

Constructors

ResponsiveUtils()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

isDesktop(BuildContext context) bool
Returns true if the device screen width is 1024 pixels or more, typically considered a desktop device.
isMobile(BuildContext context) bool
Returns true if the device screen width is less than 600 pixels, typically considered a mobile device.
isTablet(BuildContext context) bool
Returns true if the device screen width is between 600 and 1024 pixels, typically considered a tablet device.
screenHeight(BuildContext context) double
Returns the height of the current screen.
screenWidth(BuildContext context) double
Returns the width of the current screen.