isDesktop static method
Returns true if the device screen width is 1024 pixels or more,
typically considered a desktop device.
Implementation
static bool isDesktop(BuildContext context) =>
MediaQuery.of(context).size.width >= 1024;
Returns true if the device screen width is 1024 pixels or more,
typically considered a desktop device.
static bool isDesktop(BuildContext context) =>
MediaQuery.of(context).size.width >= 1024;