isMobile static method
Returns true if the device screen width is less than 600 pixels,
typically considered a mobile device.
Implementation
static bool isMobile(BuildContext context) =>
MediaQuery.of(context).size.width < 600;
Returns true if the device screen width is less than 600 pixels,
typically considered a mobile device.
static bool isMobile(BuildContext context) =>
MediaQuery.of(context).size.width < 600;