widgets/responsive_builder library
Classes
- ResponsiveBuilder
- A responsive widget builder that renders different widgets based on the screen width.
Typedefs
- ResponsiveWidgetBuilder = Widget Function(BuildContext context)
- A typedef that represents a widget builder function which provides a BuildContext.