ResponsiveBuilder class
A responsive widget builder that renders different widgets based on the screen width.
It allows you to provide separate widgets for mobile, tablet, and desktop views, and automatically selects the appropriate one based on the current screen size.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- ResponsiveBuilder
Constructors
- ResponsiveBuilder({Key? key, required ResponsiveWidgetBuilder mobile, ResponsiveWidgetBuilder? tablet, ResponsiveWidgetBuilder? desktop})
-
Creates a ResponsiveBuilder with required
mobilelayout and optionaltabletanddesktoplayouts.const
Properties
- desktop → ResponsiveWidgetBuilder?
-
The optional widget builder for desktop layout.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- mobile → ResponsiveWidgetBuilder
-
The widget builder for mobile layout.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tablet → ResponsiveWidgetBuilder?
-
The optional widget builder for tablet layout.
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited